@@ -6,6 +6,7 @@ import logging
 import math
 import pathlib
 import re
+import warnings
 from functools import lru_cache
 from typing import (
     Any,
@@ -166,8 +167,9 @@ class ScannerBase(abc.ABC):
             self.logger.info("Initializing included paths")
             patterns = list(self.global_options.include_path_patterns or ())
             if self.global_options.include_paths:
-                self.logger.warning(
-                    "DEPRECATED --include-paths, use --include-path-patterns"
+                warnings.warn(
+                    "--include-paths is deprecated and will be removed in v3.0. Use --include-path-patterns instead.",
+                    DeprecationWarning,
                 )
                 patterns += self.global_options.include_paths.readlines()
                 self.global_options.include_paths.close()
@@ -188,9 +190,7 @@ class ScannerBase(abc.ABC):
         if self._excluded_entropy is None:
             self.logger.info("Initializing excluded entropy patterns")
             patterns = list(self.global_options.exclude_entropy_patterns or ())
-            self._excluded_entropy = (
-                config.compile_rules(set(patterns)) if patterns else []
-            )
+            self._excluded_entropy = config.compile_rules(patterns) if patterns else []
             self.logger.debug(
                 "Excluded entropy was initialized as: %s", self._excluded_entropy
             )
@@ -206,8 +206,9 @@ class ScannerBase(abc.ABC):
             self.logger.info("Initializing excluded paths")
             patterns = list(self.global_options.exclude_path_patterns or ())
             if self.global_options.exclude_paths:
-                self.logger.warning(
-                    "DEPRECATED --exclude-paths, use --exclude-path-patterns"
+                warnings.warn(
+                    "--exclude-paths is deprecated and will be removed in v3.0. Use --exclude-path-patterns instead.",
+                    DeprecationWarning,
                 )
                 patterns += self.global_options.exclude_paths.readlines()
                 self.global_options.exclude_paths.close()
@@ -285,7 +286,7 @@ class ScannerBase(abc.ABC):
 
     @staticmethod
     @lru_cache(maxsize=None)
-    def rule_matches(rule: Rule, string: str, path: str) -> bool:
+    def rule_matches(rule: Rule, string: str, line: str, path: str) -> bool:
         """
         Match string and path against rule.
 
@@ -295,13 +296,20 @@ class ScannerBase(abc.ABC):
         :return: True if string and path matched, False otherwise.
         """
         match = False
-        if rule.pattern:
-            match = rule.pattern.search(string) is not None
-        if rule.path_pattern:
-            match = match and rule.path_pattern.search(path) is not None
+        if rule.re_match_type == "match":
+            if rule.pattern:
+                match = rule.pattern.match(string) is not None
+            if rule.path_pattern:
+                match = match and rule.path_pattern.match(path) is not None
+        elif rule.re_match_type == "search":
+            if rule.pattern:
+                match = rule.pattern.search(line) is not None
+            if rule.path_pattern:
+                match = match and rule.path_pattern.search(path) is not None
+
         return match
 
-    def entropy_string_is_excluded(self, string: str, path: str) -> bool:
+    def entropy_string_is_excluded(self, string: str, line: str, path: str) -> bool:
         """Find whether the signature of some data has been excluded in configuration.
 
         :param string: String to check against rule pattern
@@ -310,7 +318,8 @@ class ScannerBase(abc.ABC):
         """
 
         return bool(self.excluded_entropy) and any(
-            ScannerBase.rule_matches(p, string, path) for p in self.excluded_entropy
+            ScannerBase.rule_matches(p, string, line, path)
+            for p in self.excluded_entropy
         )
 
     @lru_cache(maxsize=None)
@@ -360,15 +369,23 @@ class ScannerBase(abc.ABC):
             if self.global_options.regex and self.rules_regexes:
                 issues += self.scan_regex(chunk)
             if self.global_options.entropy:
-                issues += self.scan_entropy(chunk)
+                issues += self.scan_entropy(
+                    chunk,
+                    self.global_options.b64_entropy_score,
+                    self.global_options.hex_entropy_score,
+                )
         self._issues = issues
         self.logger.info("Found %d issues.", len(self._issues))
         return self._issues
 
-    def scan_entropy(self, chunk: types.Chunk) -> List[Issue]:
+    def scan_entropy(
+        self, chunk: types.Chunk, b64_entropy_score: float, hex_entropy_score: float
+    ) -> List[Issue]:
         """Scan a chunk of data for apparent high entropy.
 
         :param chunk: The chunk of data to be scanned
+        :param b64_entropy_score: Base64 entropy score
+        :param hex_entropy_score: Hexadecimal entropy score
         """
         issues: List[Issue] = []
         for line in chunk.contents.split("\n"):
@@ -378,12 +395,12 @@ class ScannerBase(abc.ABC):
 
                 for string in b64_strings:
                     issues += self.evaluate_entropy_string(
-                        chunk, line, string, BASE64_CHARS, 4.5
+                        chunk, line, string, BASE64_CHARS, b64_entropy_score
                     )
 
                 for string in hex_strings:
                     issues += self.evaluate_entropy_string(
-                        chunk, line, string, HEX_CHARS, 3
+                        chunk, line, string, HEX_CHARS, hex_entropy_score
                     )
 
         return issues
@@ -409,7 +426,7 @@ class ScannerBase(abc.ABC):
         if not self.signature_is_excluded(string, chunk.file_path):
             entropy_score = self.calculate_entropy(string, chars)
             if entropy_score > min_entropy_score:
-                if self.entropy_string_is_excluded(line, chunk.file_path):
+                if self.entropy_string_is_excluded(string, line, chunk.file_path):
                     self.logger.debug("line containing entropy was excluded: %s", line)
                 else:
                     return [Issue(types.IssueType.Entropy, string, chunk)]
