@@ -26,6 +26,8 @@ class GlobalOptions:
         "quiet",
         "log_timestamps",
         "compact",
+        "b64_entropy_score",
+        "hex_entropy_score",
     )
     json: bool
     rules: Tuple[TextIO, ...]
@@ -46,6 +48,8 @@ class GlobalOptions:
     quiet: bool
     log_timestamps: bool
     compact: bool
+    b64_entropy_score: float
+    hex_entropy_score: float
 
 
 @dataclass
@@ -73,10 +77,11 @@ class Chunk:
 
 @dataclass
 class Rule:
-    __slots__ = ("name", "pattern", "path_pattern")
+    __slots__ = ("name", "pattern", "path_pattern", "re_match_type")
     name: Optional[str]
     pattern: Pattern
     path_pattern: Optional[Pattern]
+    re_match_type: str
 
     def __hash__(self) -> int:
         if self.path_pattern:
